@@ -120,28 +120,21 @@ miner_files_create_folder_information_element (TrackerMinerFiles *miner,
 	return resource;
 }
 
-static TrackerResource *
-miner_files_create_text_file_information_element (TrackerMinerFiles *miner,
-                                                  GFile             *file,
-                                                  const gchar       *mime_type)
+gchar *
+get_content_type (GFile     *file,
+		  GFileInfo *file_info)
 {
-	TrackerResource *resource;
-	GStrv rdf_types;
-	const gchar *urn;
-	int i;
+	g_autoptr (GFileInfo) content_info = NULL;
 
-	urn = tracker_miner_fs_get_identifier (TRACKER_MINER_FS (miner),
-	                                       file);
-	resource = tracker_resource_new (urn);
+	if (!g_file_info_has_attribute (file_info, G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE)) {
+		content_info =
+			g_file_query_info (file,
+					   G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE,
+					   G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,
+					   NULL, NULL);
+	}
 
-	rdf_types = tracker_extract_module_manager_get_rdf_types (mime_type);
-
-	for (i = 0; rdf_types[i]; i++)
-		tracker_resource_add_uri (resource, "rdf:type", rdf_types[i]);
-
-	g_strfreev (rdf_types);
-
-	return resource;
+	return g_strdup (g_file_info_get_content_type (content_info ? content_info : file_info));
 }
 
 void
@@ -153,10 +146,11 @@ tracker_miner_files_process_file (TrackerMinerFS      *fs,
 {
 	TrackerIndexingTree *indexing_tree;
 	g_autoptr (TrackerResource) resource = NULL, folder_resource = NULL, graph_file = NULL;
-	const gchar *mime_type, *graph;
+	const gchar *graph;
 	const gchar *parent_urn;
 	g_autoptr (GFile) parent = NULL;
 	g_autofree gchar *uri = NULL;
+	g_autofree gchar *mime_type = NULL;
 	gboolean is_directory, is_root;
 	g_autoptr (GDateTime) modified = NULL;
 #ifdef GIO_SUPPORTS_CREATION_TIME
@@ -166,9 +160,12 @@ tracker_miner_files_process_file (TrackerMinerFS      *fs,
 	g_autofree gchar *time_str = NULL;
 #endif
 
+	mime_type = get_content_type (file, file_info);
+	if (!mime_type)
+		return;
+
 	uri = g_file_get_uri (file);
 	indexing_tree = tracker_miner_fs_get_indexing_tree (fs);
-	mime_type = g_file_info_get_content_type (file_info);
 
 	is_root = tracker_indexing_tree_file_is_root (indexing_tree, file);
 	is_directory = (g_file_info_get_file_type (file_info) == G_FILE_TYPE_DIRECTORY ?
@@ -247,21 +244,6 @@ tracker_miner_files_process_file (TrackerMinerFS      *fs,
 		tracker_resource_set_int64 (graph_file, "nfo:fileSize",
 		                            g_file_info_get_size (file_info));
 		miner_files_add_to_datasource (TRACKER_MINER_FILES (fs), file, graph_file, NULL);
-
-		if (tracker_extract_module_manager_check_fallback_rdf_type (mime_type,
-		                                                            "nfo:PlainTextDocument") &&
-		    !tracker_miner_files_check_allowed_text_file (TRACKER_MINER_FILES (fs), file)) {
-			TrackerResource *text_file;
-
-			/* We let disallowed text files have a shallow nie:InformationElement */
-			text_file = miner_files_create_text_file_information_element (TRACKER_MINER_FILES (fs),
-			                                                              file, mime_type);
-			tracker_resource_set_take_relation (graph_file, "nie:interpretedAs", text_file);
-			tracker_resource_set_uri (text_file, "nie:isStoredAs", uri);
-
-			tracker_resource_set_string (graph_file, "tracker:extractorHash",
-			                             tracker_extract_module_manager_get_hash (mime_type));
-		}
 	}
 
 	if (is_directory) {
@@ -284,7 +266,8 @@ tracker_miner_files_process_file_attributes (TrackerMinerFS      *fs,
 {
 	g_autoptr (TrackerResource) resource = NULL, graph_file = NULL;
 	g_autofree gchar *uri = NULL;
-	const gchar *mime_type, *graph;
+	g_autofree gchar *mime_type = NULL;
+	const gchar *graph;
 	g_autoptr (GDateTime) modified = NULL;
 #ifdef GIO_SUPPORTS_CREATION_TIME
 	g_autoptr (GDateTime) accessed = NULL, created = NULL;
@@ -293,24 +276,18 @@ tracker_miner_files_process_file_attributes (TrackerMinerFS      *fs,
 	time_t time_;
 #endif
 
+	mime_type = get_content_type (file, info);
+	if (!mime_type)
+		return;
+
 	uri = g_file_get_uri (file);
 	resource = tracker_resource_new (uri);
 	tracker_resource_add_uri (resource, "rdf:type", "nfo:FileDataObject");
 
-	if (!info) {
-		info = g_file_query_info (file,
-		                          G_FILE_ATTRIBUTE_TIME_MODIFIED ","
-		                          G_FILE_ATTRIBUTE_TIME_ACCESS ","
-		                          G_FILE_ATTRIBUTE_TIME_CREATED,
-		                          G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,
-		                          NULL, NULL);
-	}
-
 	modified = g_file_info_get_modification_date_time (info);
 	if (!modified)
 		modified = g_date_time_new_from_unix_utc (0);
 
-	mime_type = g_file_info_get_content_type (info);
 	graph = tracker_extract_module_manager_get_graph (mime_type);
 
 	/* Update nfo:fileLastModified */
