@@ -25,10 +25,10 @@
 #include "tracker-extract-decorator.h"
 #include "tracker-extract-persistence.h"
 
+#define THROTTLED_TIMEOUT_MS 10
+
 enum {
-	PROP_0,
-	PROP_EXTRACTOR,
-	PROP_PERSISTENCE,
+	PROP_EXTRACTOR = 1
 };
 
 typedef struct _TrackerExtractDecoratorPrivate TrackerExtractDecoratorPrivate;
@@ -46,12 +46,19 @@ struct _TrackerExtractDecoratorPrivate {
 	TrackerExtract *extractor;
 	GTimer *timer;
 	gboolean extracting;
+	gboolean paused_on_low_battery;
 
 	TrackerSparqlStatement *update_hash;
 	TrackerSparqlStatement *delete_file;
 
 	TrackerExtractPersistence *persistence;
 	GVolumeMonitor *volume_monitor;
+
+	guint throttle_id;
+
+#ifdef HAVE_POWER
+	TrackerPower *power;
+#endif /* HAVE_POWER */
 };
 
 static void decorator_get_next_file (TrackerDecorator *decorator);
@@ -78,12 +85,6 @@ tracker_extract_decorator_get_property (GObject    *object,
 	case PROP_EXTRACTOR:
 		g_value_set_object (value, priv->extractor);
 		break;
-	case PROP_PERSISTENCE:
-		g_value_set_object (value, priv->persistence);
-		break;
-	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
-		break;
 	}
 }
 
@@ -101,12 +102,6 @@ tracker_extract_decorator_set_property (GObject      *object,
 	case PROP_EXTRACTOR:
 		priv->extractor = g_value_dup_object (value);
 		break;
-	case PROP_PERSISTENCE:
-		priv->persistence = g_value_dup_object (value);
-		break;
-	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
-		break;
 	}
 }
 
@@ -129,6 +124,35 @@ load_statement (TrackerExtractDecorator *decorator,
 	                                                                NULL);
 }
 
+static void
+persistence_ignore_file (GFile    *file,
+                         gpointer  user_data)
+{
+	TrackerExtractDecorator *decorator = user_data;
+
+	decorator_ignore_file (file, decorator, "Crash/hang handling file", NULL);
+}
+
+#ifdef HAVE_POWER
+static void
+low_battery_cb (TrackerExtractDecorator *extract_decorator)
+{
+	TrackerExtractDecoratorPrivate *priv =
+		tracker_extract_decorator_get_instance_private (extract_decorator);
+	gboolean on_low_battery;
+
+	on_low_battery = tracker_power_get_on_low_battery (priv->power);
+
+	if (on_low_battery && !priv->paused_on_low_battery) {
+		tracker_miner_pause (TRACKER_MINER (extract_decorator));
+		priv->paused_on_low_battery = TRUE;
+	} else if (!on_low_battery && priv->paused_on_low_battery) {
+		tracker_miner_resume (TRACKER_MINER (extract_decorator));
+		priv->paused_on_low_battery = FALSE;
+	}
+}
+#endif /* HAVE_POWER */
+
 static void
 tracker_extract_decorator_constructed (GObject *object)
 {
@@ -141,6 +165,18 @@ tracker_extract_decorator_constructed (GObject *object)
 
 	priv->update_hash = load_statement (decorator, "update-hash.rq");
 	priv->delete_file = load_statement (decorator, "delete-file.rq");
+
+	priv->persistence = tracker_extract_persistence_initialize (persistence_ignore_file,
+	                                                            decorator);
+
+#ifdef HAVE_POWER
+	priv->power = tracker_power_new ();
+	if (priv->power) {
+		g_signal_connect_swapped (priv->power, "notify::on-low-battery",
+		                          G_CALLBACK (low_battery_cb),
+		                          object);
+	}
+#endif /* HAVE_POWER */
 }
 
 static void
@@ -150,6 +186,9 @@ tracker_extract_decorator_finalize (GObject *object)
 
 	priv = tracker_extract_decorator_get_instance_private (TRACKER_EXTRACT_DECORATOR (object));
 
+	if (priv->throttle_id)
+		g_source_remove (priv->throttle_id);
+
 	if (priv->extractor)
 		g_object_unref (priv->extractor);
 
@@ -160,7 +199,10 @@ tracker_extract_decorator_finalize (GObject *object)
 
 	g_clear_object (&priv->update_hash);
 	g_clear_object (&priv->delete_file);
-	g_clear_object (&priv->persistence);
+
+#ifdef HAVE_POWER
+	g_clear_object (&priv->power);
+#endif /* HAVE_POWER */
 
 	G_OBJECT_CLASS (tracker_extract_decorator_parent_class)->finalize (object);
 }
@@ -176,6 +218,9 @@ ensure_data (TrackerExtractInfo *info)
 	gint i;
 
 	resource = tracker_extract_info_get_resource (info);
+	if (!resource)
+		return;
+
 	mimetype = tracker_extract_info_get_mimetype (info);
 	file = tracker_extract_info_get_file (info);
 	uri = g_file_get_uri (file);
@@ -223,6 +268,40 @@ tracker_extract_decorator_update (TrackerDecorator   *decorator,
 		tracker_batch_add_resource (batch, graph, resource);
 }
 
+static gboolean
+throttle_next_item_cb (gpointer user_data)
+{
+	TrackerExtractDecoratorPrivate *priv =
+		tracker_extract_decorator_get_instance_private (user_data);
+
+	priv->throttle_id = 0;
+	decorator_get_next_file (user_data);
+	return G_SOURCE_REMOVE;
+}
+
+static void
+throttle_next_item (TrackerDecorator *decorator)
+{
+	TrackerExtractDecorator *extract_decorator =
+		TRACKER_EXTRACT_DECORATOR (decorator);
+	TrackerExtractDecoratorPrivate *priv =
+		tracker_extract_decorator_get_instance_private (extract_decorator);
+
+#ifdef HAVE_POWER
+	if (priv->power && tracker_power_get_on_battery (priv->power)) {
+		priv->throttle_id =
+			g_timeout_add (THROTTLED_TIMEOUT_MS,
+				       throttle_next_item_cb,
+				       decorator);
+	} else
+#endif
+	{
+		priv->throttle_id =
+			g_idle_add (throttle_next_item_cb,
+				    decorator);
+	}
+}
+
 static void
 get_metadata_cb (TrackerExtract *extract,
                  GAsyncResult   *result,
@@ -235,7 +314,7 @@ get_metadata_cb (TrackerExtract *extract,
 	priv = tracker_extract_decorator_get_instance_private (TRACKER_EXTRACT_DECORATOR (data->decorator));
 	info = tracker_extract_file_finish (extract, result, &error);
 
-	tracker_extract_persistence_set_file (priv->persistence, NULL);
+	tracker_extract_persistence_remove_file (priv->persistence, data->file);
 
 	if (data->cancellable && data->signal_id != 0) {
 		g_cancellable_disconnect (data->cancellable, data->signal_id);
@@ -253,7 +332,8 @@ get_metadata_cb (TrackerExtract *extract,
 	}
 
 	priv->extracting = FALSE;
-	decorator_get_next_file (data->decorator);
+
+	throttle_next_item (data->decorator);
 
 	tracker_decorator_info_unref (data->decorator_info);
 	g_object_unref (data->file);
@@ -272,7 +352,7 @@ task_cancellable_cancelled_cb (GCancellable *cancellable,
 	 * this as a failed operation.
 	 */
 	priv = tracker_extract_decorator_get_instance_private (TRACKER_EXTRACT_DECORATOR (data->decorator));
-	tracker_extract_persistence_set_file (priv->persistence, NULL);
+	tracker_extract_persistence_remove_file (priv->persistence, data->file);
 	uri = g_file_get_uri (data->file);
 
 	g_debug ("Cancelled task for '%s' was currently being "
@@ -345,7 +425,7 @@ decorator_get_next_file (TrackerDecorator *decorator)
 	              g_message ("[Decorator] Extracting metadata for '%s'",
 	                         tracker_decorator_info_get_url (info)));
 
-	tracker_extract_persistence_set_file (priv->persistence, data->file);
+	tracker_extract_persistence_add_file (priv->persistence, data->file);
 
 	g_set_object (&data->cancellable, cancellable);
 
@@ -370,6 +450,8 @@ tracker_extract_decorator_paused (TrackerMiner *miner)
 	priv = tracker_extract_decorator_get_instance_private (TRACKER_EXTRACT_DECORATOR (miner));
 	g_debug ("Decorator paused");
 
+	g_clear_handle_id (&priv->throttle_id, g_source_remove);
+
 	if (priv->timer)
 		g_timer_stop (priv->timer);
 }
@@ -389,22 +471,6 @@ tracker_extract_decorator_resumed (TrackerMiner *miner)
 	decorator_get_next_file (TRACKER_DECORATOR (miner));
 }
 
-static void
-tracker_extract_decorator_started (TrackerMiner *miner)
-{
-	TrackerExtractDecorator *decorator = TRACKER_EXTRACT_DECORATOR (miner);
-	TrackerExtractDecoratorPrivate *priv =
-		tracker_extract_decorator_get_instance_private (decorator);
-	GFile *file;
-
-	file = tracker_extract_persistence_get_file (priv->persistence);
-
-	if (file)
-		decorator_ignore_file (file, decorator, "Crash/hang handling file", NULL);
-
-	TRACKER_MINER_CLASS (tracker_extract_decorator_parent_class)->started (miner);
-}
-
 static void
 tracker_extract_decorator_items_available (TrackerDecorator *decorator)
 {
@@ -474,7 +540,6 @@ tracker_extract_decorator_class_init (TrackerExtractDecoratorClass *klass)
 
 	miner_class->paused = tracker_extract_decorator_paused;
 	miner_class->resumed = tracker_extract_decorator_resumed;
-	miner_class->started = tracker_extract_decorator_started;
 
 	decorator_class->items_available = tracker_extract_decorator_items_available;
 	decorator_class->finished = tracker_extract_decorator_finished;
@@ -490,14 +555,6 @@ tracker_extract_decorator_class_init (TrackerExtractDecoratorClass *klass)
 	                                                      G_PARAM_READWRITE |
 	                                                      G_PARAM_CONSTRUCT_ONLY |
 	                                                      G_PARAM_STATIC_STRINGS));
-	g_object_class_install_property (object_class,
-	                                 PROP_PERSISTENCE,
-	                                 g_param_spec_object ("persistence",
-	                                                      NULL, NULL,
-	                                                      TRACKER_TYPE_EXTRACT_PERSISTENCE,
-	                                                      G_PARAM_READWRITE |
-	                                                      G_PARAM_CONSTRUCT_ONLY |
-	                                                      G_PARAM_STATIC_STRINGS));
 }
 
 static void
@@ -532,7 +589,7 @@ decorator_ignore_file (GFile                   *file,
 	}
 
 	if (hash) {
-		g_signal_emit_by_name (decorator, "raise-error", file, error_message, extra_info);
+		tracker_error_report (file, error_message, extra_info);
 
 		tracker_sparql_statement_bind_string (priv->update_hash, "file", uri);
 		tracker_sparql_statement_bind_string (priv->update_hash, "hash", hash);
@@ -541,8 +598,10 @@ decorator_ignore_file (GFile                   *file,
 	}
 
 	if (!removed_hash) {
-		if (info_error && !g_error_matches (info_error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND))
-			g_signal_emit_by_name (decorator, "raise-error", file, error_message, extra_info);
+		if (!info_error || g_error_matches (info_error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND))
+			tracker_error_report_delete (file);
+		else
+			tracker_error_report (file, info_error->message, NULL);
 
 		g_clear_error (&error);
 		tracker_sparql_statement_bind_string (priv->delete_file, "file", uri);
@@ -586,16 +645,14 @@ tracker_extract_decorator_init (TrackerExtractDecorator *decorator)
 }
 
 TrackerDecorator *
-tracker_extract_decorator_new (TrackerSparqlConnection    *connection,
-                               TrackerExtract             *extract,
-			       TrackerExtractPersistence  *persistence,
-                               GCancellable               *cancellable,
-                               GError                    **error)
+tracker_extract_decorator_new (TrackerSparqlConnection  *connection,
+                               TrackerExtract           *extract,
+                               GCancellable             *cancellable,
+                               GError                  **error)
 {
 	return g_initable_new (TRACKER_TYPE_EXTRACT_DECORATOR,
 	                       cancellable, error,
 	                       "connection", connection,
 	                       "extractor", extract,
-	                       "persistence", persistence,
 	                       NULL);
 }
