@@ -24,7 +24,6 @@
 
 #include "tracker-extract.h"
 #include "tracker-decorator.h"
-#include "tracker-extract-persistence.h"
 
 G_BEGIN_DECLS
 
@@ -48,11 +47,10 @@ struct TrackerExtractDecoratorClass {
 
 GType              tracker_extract_decorator_get_type (void) G_GNUC_CONST;
 
-TrackerDecorator * tracker_extract_decorator_new (TrackerSparqlConnection   *connection,
-                                                  TrackerExtract            *extractor,
-                                                  TrackerExtractPersistence *persistence,
-                                                  GCancellable              *cancellable,
-                                                  GError                   **error);
+TrackerDecorator * tracker_extract_decorator_new (TrackerSparqlConnection  *connection,
+                                                  TrackerExtract           *extractor,
+                                                  GCancellable             *cancellable,
+                                                  GError                  **error);
 
 G_END_DECLS
 
